@@ -1,10 +1,10 @@
 package Org::To::HTML;
 
-our $DATE = '2016-12-24'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use vars qw($VERSION);
 
@@ -410,7 +410,7 @@ Org::To::HTML - Export Org document to HTML
 
 =head1 VERSION
 
-This document describes version 0.21 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2016-12-24.
+This document describes version 0.22 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -450,7 +450,11 @@ Export document to HTML.
 =head1 FUNCTIONS
 
 
-=head2 org_to_html(%args) -> [status, msg, result, meta]
+=head2 org_to_html
+
+Usage:
+
+ org_to_html(%args) -> [status, msg, result, meta]
 
 Export Org document to HTML.
 
@@ -575,7 +579,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
