@@ -1,12 +1,12 @@
 package Org::To::Role;
 
-our $DATE = '2016-12-24'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use Moo::Role;
 use String::Escape qw/elide printable/;
@@ -47,7 +47,7 @@ Org::To::Role - Role for Org exporters
 
 =head1 VERSION
 
-This document describes version 0.21 of Org::To::Role (from Perl distribution Org-To-HTML), released on 2016-12-24.
+This document describes version 0.22 of Org::To::Role (from Perl distribution Org-To-HTML), released on 2017-07-10.
 
 =head1 HOMEPAGE
 
@@ -71,7 +71,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
